35#include <hip/hip_runtime.h>
53 void *
u,
int *n,
void *
gd,
int *
nb,
54 void *b,
void *
bo,
int *op,
57 if ((*m) == 0)
return;
60 const dim3 nblcks(((*m)+ 1024 - 1)/ 1024, 1, 1);
68 *
nb, (
int *) b, (
int *)
bo);
76 *
nb, (
int *) b, (
int *)
bo);
84 *
nb, (
int *) b, (
int *)
bo);
92 *
nb, (
int *) b, (
int *)
bo);
102 void *
u,
int *n,
void *
gd,
103 int *
nb,
void *b,
void *
bo,
106 if ((*m) == 0)
return;
109 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
115 *
nb, (
int *) b, (
int *)
bo);
130 (
real *) u_d, (
real *) buf_d + offset,
131 (
int *) dof_d + offset, n);
177 int offset,
int n,
int nc,
int ns,
186 (
int *) dof_d + offset, n,
nc,
ns);
194 int offset,
int n,
int nc,
int ns,
204 u_d, buf_d +
nc*offset, dof_d + offset, n,
nc,
ns);
209 u_d, buf_d +
nc*offset, dof_d + offset, n,
nc,
ns);
214 u_d, buf_d +
nc*offset, dof_d + offset, n,
nc,
ns);
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
void hip_gs_unpack(real *u_d, int op, real *buf_d, int *dof_d, int offset, int n, hipStream_t stream)
void hip_scatter_kernel(void *v, int *m, void *dg, void *u, int *n, void *gd, int *nb, void *b, void *bo, hipStream_t stream)
void hip_gs_pack(void *u_d, void *buf_d, void *dof_d, int offset, int n, hipStream_t stream)
void hip_gs_pack_vec(void *u_d, void *buf_d, void *dof_d, int offset, int n, int nc, int ns, hipStream_t stream)
void hip_gs_unpack_vec(real *u_d, int op, real *buf_d, int *dof_d, int offset, int n, int nc, int ns, hipStream_t stream)
void hip_gather_kernel(void *v, int *m, int *o, void *dg, void *u, int *n, void *gd, int *nb, void *b, void *bo, int *op, hipStream_t stream)